package
Version:
v0.0.0-...-0da4f38
Opens a new window with list of versions in this module.
Published: Sep 21, 2015
License: BSD-3-Clause
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 1
Opens a new window with list of known importers.
Documentation
¶
type Apt struct {
Pkg string `tachyon:"pkg"`
State string `tachyon:"state" enum:"present,install,absent,remove"`
Cache bool `tachyon:"update_cache"`
CacheTime string `tachyon:"cache_time"`
Dry bool `tachyon:"dryrun"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.